@@ -72,6 +72,7 @@ public class MC3000GathererThread extends Thread {
 	boolean[]						isAlerted4Finish						= { false, false, false, false };
 	int									retryCounterRest_sec				= MC3000GathererThread.WAIT_TIME_RETRYS_MAX_SEC;	//maximal evaluated resting time plus 1 Min
 	int									retryCounterEnd_sec					= MC3000GathererThread.WAIT_TIME_RETRYS_END_SEC;	//60/4 = 15 Min
+	int									lastNumberDisplayableRecords= 0;
 
 	/**
 	 * data gatherer thread definition 
@@ -265,6 +266,9 @@ public class MC3000GathererThread extends Thread {
 										recordSet5.setAllDisplayable();
 										String description = recordSet5.getRecordSetDescription();
 										recordSet5.setRecordSetDescription(description + GDE.LINE_SEPARATOR + this.device.getHardwareString() + GDE.STRING_BLANK + this.device.getFirmwareString());
+										if (this.channels.getActiveChannelNumber() == 5)
+											this.channels.switchChannel(5, recordSetKey5);
+										slotChannel.switchRecordSet(recordSetKey5);
 									}
 								}
 								if (recordSet5 != null) recordSet5.addPoints(points5);
@@ -273,8 +277,11 @@ public class MC3000GathererThread extends Thread {
 									this.device.updateVisibilityStatus(recordSet5, true);
 								}
 							}
-							
-							MC3000GathererThread.this.application.updateAllTabs(false);
+							RecordSet activeRecordSet = this.channels.getActiveChannel().getActiveRecordSet();
+							if (activeRecordSet != null && activeRecordSet.size() > 0) {
+								MC3000GathererThread.this.application.updateAllTabs(false, this.lastNumberDisplayableRecords != activeRecordSet.getConfiguredDisplayable());
+								this.lastNumberDisplayableRecords = activeRecordSet.getConfiguredDisplayable();
+							}					
 							this.application.setStatusMessage(GDE.STRING_EMPTY);
 							
 							//check for all processing finished and stop gathering after 15 min
@@ -425,7 +432,8 @@ public class MC3000GathererThread extends Thread {
 				recordSet.get(7).setUnit(device.getTemperatureUnit());
 				//channel.applyTemplate(recordSetKey, false);
 				// switch the active record set if the current record set is child of active channel
-				this.channels.switchChannel(slotChannel.getNumber(), processRecordSetKey);
+				if (this.channels.getActiveChannelNumber() != 5)
+					this.channels.switchChannel(slotChannel.getNumber(), processRecordSetKey);
 				slotChannel.switchRecordSet(processRecordSetKey);
 				String description = String.format("%s%s%s %s; Memory # %02d", 
 						recordSet.getRecordSetDescription(), GDE.LINE_SEPARATOR, this.device.getHardwareString(), this.device.getFirmwareString(), this.device.getBatteryMemoryNumber(number, this.usbInterface)); //$NON-NLS-1$
